pub struct SemVer {
pub major: u8,
pub minor: u8,
pub patch: u8,
}Expand description
A semantic library version, ordered by major, then minor, then patch.
The field declaration order matters: the derived Ord/PartialOrd compare fields
lexicographically in declaration order, which is exactly semantic-version precedence.
A semantic version can often also take a suffix, e.g. “alpha”, “beta”, “rc1”, etc.
We’re not going to model that here because it’s not useful for versioning serialized states.
Fields
major: u8minor: u8patch: u8Trait Implementations
Sourceimpl Ord for SemVer
impl Ord for SemVer
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialOrd for SemVer
impl PartialOrd for SemVer
impl Copy for SemVer
impl Eq for SemVer
impl StructuralPartialEq for SemVer